##  Overview
Fact sheet relations represent the connections or relationships between different fact sheets, showing how they interact or relate to each other.
In the standard meta model configuration, relations between certain fact sheet types are predefined. To get an overview of the meta model and fact sheet relations, see [Meta Model](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts.").
The relation key reflects the direction of the relation, for example:
  * relApplicationToITComponent: Relation from an application to an IT component.
  * relITComponentToApplication: Relation from an IT component to an application.


You can create or delete relations to adjust the meta model configuration to your organization’s needs.
